@@ -2,13 +2,16 @@ import click
 import click_config_file
 
 from montecarlodata import settings
+from montecarlodata.common import create_mc_client
 from montecarlodata.iac.mc_config_service import MonteCarloConfigService
+from montecarlodata.rules.rule_service import RuleService
+
 
 
 @click.group(help='Manage monitors.')
 def monitors():
     """
-    Group for any collector related subcommands
+    Group for any monitor related subcommands
     """
     pass
 
@@ -34,4 +37,18 @@ def apply(ctx, project_dir, namespace, dry_run):
 @click.pass_obj
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def delete(ctx, project_dir, namespace, dry_run):
-    MonteCarloConfigService(config=ctx['config'], project_dir=project_dir).delete(namespace, dry_run=dry_run)
\ No newline at end of file
+    MonteCarloConfigService(config=ctx['config'], project_dir=project_dir).delete(namespace, dry_run=dry_run)
+
+@monitors.command(name='list', help='List monitors ordered by update recency.')
+@click.option('--limit', required=False, default=100, type=click.INT, show_default=True, help='Max number of monitors to list.')
+@click.option(
+    '--rule-type',
+    required=True,
+    type=click.Choice(RuleService.RULE_TYPES, case_sensitive=False),
+    help='The type of rule to list.'
+)
+@click.pass_obj
+def list_monitors(ctx, rule_type, limit):
+    if rule_type == RuleService.PSEUDO_RULE_TYPE_CB_COMPATIBLE:
+        rule_type = RuleService.RULE_TYPE_CUSTOM_SQL
+    RuleService(client=create_mc_client(ctx)).list_rules(rule_type, limit)
